Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type NSResolver ¶
type NSResolver struct {
// LoadedChunks captures the compiled bytecode for each user-loaded namespace.
// Used by the compiler to serialize all namespaces into a bundle.
LoadedChunks map[string]*vm.CodeChunk
// LoadOrder preserves the order in which namespaces were loaded (dependency order).
LoadOrder []string
// contains filtered or unexported fields
}
func NewNSResolver ¶
func NewNSResolver(ctx *compiler.Context, path []string) *NSResolver
func (*NSResolver) SetPath ¶
func (r *NSResolver) SetPath(path []string)
Click to show internal directories.
Click to hide internal directories.